"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const throttle_1 = __importDefault(require("lodash/fp/throttle"));
exports.default = ({ activeSectionDefault = 0, offsetPx = 0, scrollingElement, sectionElementRefs = [], throttleMs = 100, }) => {
    const [activeSection, setActiveSection] = (0, react_1.useState)(activeSectionDefault);
    const handle = (0, throttle_1.default)(throttleMs, () => {
        let currentSectionId = activeSection;
        for (let i = 0; i < sectionElementRefs.length; i += 1) {
            const section = sectionElementRefs[i].current;
            // Needs to be a valid DOM Element
            if (!section || !(section instanceof Element))
                continue;
            // GetBoundingClientRect returns values relative to viewport
            if (section.getBoundingClientRect().top + offsetPx < 0) {
                currentSectionId = i;
                continue;
            }
            // No need to continue loop, if last element has been detected
            break;
        }
        setActiveSection(currentSectionId);
    });
    (0, react_1.useEffect)(() => {
        const scrollable = scrollingElement?.current ?? window;
        scrollable.addEventListener("scroll", handle);
        // Run initially
        handle();
        return () => {
            scrollable.removeEventListener("scroll", handle);
        };
    }, [sectionElementRefs, offsetPx, scrollingElement, handle]);
    return activeSection;
};
//# sourceMappingURL=index.js.map